import esbuild from "esbuild";
import process from "process";
import builtins from 'builtin-modules'
import fs from 'fs';

const banner =
`/*
THIS IS A GENERATED/BUNDLED FILE BY ESBUILD
if you want to view the source, please visit the github repository of this plugin
*/
`;

const prod = (process.argv[2] === 'production');

esbuild.build({
  banner: {
    js: banner,
  },
  entryPoints: ['src/publish.ts'],
  bundle: true,
  metafile: true,
  minify: true,
  // summary: true,
  external: [
    ...builtins
  ],
  format: 'cjs',
  watch: !prod,
  define: {"global": "window"},
  target: 'es2016',
  logLevel: "info",
  // sourcemap: prod ? false : 'inline',
  sourcemap: false,
  treeShaking: true,
  outfile: 'dist/publish.js',
}).catch(() => { process.exit(1) })
.then((res) => {
  fs.writeFileSync('./meta.json', JSON.stringify(res.metafile, null, 2));
})
